# -*- coding: utf-8 -*-
import datetime
from gisdo.queue.queue_conf import GisdoContainer
from gisdo.queue.runtime_filters import DateYearFilter, UnitFilter
from gisdo.queue.context import Context


def get_queue_index(
        index_number, unit, age_range=None, on_date=datetime.date.today,
        check_unit=True):
    """Вычисление новых показателей по очереди"""

    assert 'p{0}'.format(
        index_number.replace('.', '_')
    ) in GisdoContainer.index_filters, "Queue config failed"

    # Формирование контекста на основе показателей.
    ctx = Context(unit, on_date=on_date, first_dou_only=True)
    if check_unit:
        ctx = ctx.add_filters(UnitFilter(unit))
    if age_range is not None:
        ctx = ctx.add_filters(DateYearFilter(age_range))

    # Получение билдера
    cont = GisdoContainer()
    builder = cont.get_builder(index_number)

    # Построение QuerySet-а
    qs = builder.build(ctx)

    return qs.count()
